@@ -1,13 +1,16 @@
 """All type annotations go here."""
 
-from typing import TYPE_CHECKING, Any
 
+from typing import TYPE_CHECKING, Any, Union
 
 if TYPE_CHECKING:
-    from aio_wx_widgets.binding import Binding
+    from asyncio import AbstractEventLoop
+
+    import wx
 
     from aio_wx_widgets.controller import BaseController
-    from asyncio import AbstractEventLoop
+    from aio_wx_widgets.core.base_widget import BaseWidget, CallableItem
+    from aio_wx_widgets.core.binding import Binding
 
     try:
         import Protocol  # type: ignore
@@ -17,9 +20,13 @@ if TYPE_CHECKING:
     assert BaseController
     assert AbstractEventLoop
     assert Binding
+    assert wx
+    assert BaseWidget
 
     class Choice(Protocol):
         """Typing protocol to be used for static type checking."""
 
         label: str
         value: Any
+
+    Widget = Union[BaseWidget, wx.Window, wx.BoxSizer, CallableItem]
