@@ -1,14 +1,14 @@
 import asyncio
 import logging
-
-from wxasync import WxAsyncApp
+import os
 
 from demo.windows.main_window import MainWindow
+from wxasync import WxAsyncApp
 
 _LOGGER = logging.getLogger(__name__)
 
 if __name__ == "__main__":
-    # os.environ["DEBUGGING"] = "1"
+    os.environ["DEBUGGING"] = "1"
     logging.basicConfig(level=logging.DEBUG)
     loop = asyncio.get_event_loop()
     app = WxAsyncApp()
