@@ -1,7 +1,10 @@
 import logging
+from unittest.mock import Mock
+
 import pytest
-from aio_wx_widgets.binding import Binding, Bindable, WATCHERS
+
 from aio_wx_widgets.controller import BaseController
+from aio_wx_widgets.core.binding import WATCHERS, Binding, TwoWayBindable
 
 _LOGGER = logging.getLogger(__name__)
 #
@@ -27,14 +30,16 @@ def some_binding(some_controller):
 
 @pytest.fixture
 def some_bindable(mocker, some_binding):
-    mocker.patch.object(Bindable, "_get_ui_value")
-    mocker.patch.object(Bindable, "_set_ui_value")
+    get_ui_value = Mock()
+    set_ui_value = Mock()
+    # mocker.patch.object(TwoWayBindable, "_get_ui_value")
+    # mocker.patch.object(TwoWayBindable, "_set_ui_value")
 
-    return Bindable(some_binding)
+    return TwoWayBindable(some_binding, get_ui_value, set_ui_value)
 
 
 def test_make_binding(some_bindable, some_controller):
-    some_bindable._make_binding()
+    some_bindable.make_binding()
 
     # check if watcher is added to list of watchers.
     watchers = some_controller.__dict__[WATCHERS]["a_value"]
