@@ -1,11 +1,11 @@
 import logging
+
 import pytest
 
-
-from aio_wx_widgets.widgets.validators.validators import (
-    int_validator,
-    all_digits_validator,
+from aio_wx_widgets.core.validators import (
     ValidationError,
+    all_digits_validator,
+    int_validator,
 )
 
 _LOGGER = logging.getLogger(__name__)
@@ -14,7 +14,7 @@ _LOGGER = logging.getLogger(__name__)
 @pytest.mark.parametrize("incoming,expected", [("0", 0), ("1", 1), ("-1", -1)])
 def test_int_validator(incoming, expected):
 
-    result = int_validator(incoming)
+    result = int_validator(incoming, True)
 
     assert isinstance(result, int)
     assert result == expected
@@ -23,12 +23,12 @@ def test_int_validator(incoming, expected):
 @pytest.mark.parametrize("incoming", ["a"])
 def test_int_validator_fail(incoming):
     with pytest.raises(ValidationError):
-        int_validator(incoming)
+        int_validator(incoming, True)
 
 
 @pytest.mark.parametrize("incoming", ["0002340324"])
 def test_all_digits_validator(incoming):
-    result = all_digits_validator(incoming)
+    result = all_digits_validator(incoming, True)
 
     assert result == incoming
 
@@ -36,4 +36,4 @@ def test_all_digits_validator(incoming):
 @pytest.mark.parametrize("incoming", ["000234a0324"])
 def test_all_digits_validator_fail(incoming):
     with pytest.raises(ValidationError):
-        all_digits_validator(incoming)
+        all_digits_validator(incoming, True)
